
from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.features.i18nexample.i18nexample import TranslatedUI

web.site_root = TranslatedUI
